From fbca5c0c5deaf17093970a904c5c0a7a5667bb4f Mon Sep 17 00:00:00 2001
From: Nicola Demo <demo.nicola@gmail.com>
Date: Tue, 22 Mar 2016 23:25:36 +0100
Subject: [PATCH] Added small description to colorize option in hyper_L

---
 include/deal.II/grid/grid_generator.h | 12 ++++++++----
 source/grid/grid_generator.cc         | 10 +++++++---
 2 files changed, 15 insertions(+), 7 deletions(-)

diff --git a/source/grid/grid_generator.cc b/source/grid/grid_generator.cc
index e32577f2a6..429f5c8613 100644
--- a/source/grid/grid_generator.cc
+++ b/source/grid/grid_generator.cc
@@ -2077,7 +2077,6 @@ namespace GridGenerator
 
 
 
-//TODO: Colorize edges as circumference, left and right radius
 // Implementation for 2D only
   template <>
   void
@@ -2112,7 +2111,7 @@ namespace GridGenerator
     tria.create_triangulation (
       std::vector<Point<2> >(&vertices[0], &vertices[8]),
       cells,
-      SubCellData());       // no boundary information
+      SubCellData());
 
     if (colorize)
       {
@@ -2732,7 +2731,7 @@ namespace GridGenerator
   hyper_L (Triangulation<3> &tria,
            const double      a,
            const double      b,
-           const bool)
+           const bool        colorize)
   {
     // we slice out the top back right
     // part of the cube
@@ -2792,6 +2791,11 @@ namespace GridGenerator
       std::vector<Point<3> >(&vertices[0], &vertices[26]),
       cells,
       SubCellData());       // no boundary information
+
+    if (colorize)
+      {
+        Assert (false, ExcNotImplemented());
+      } 
   }
 
 
diff --git a/include/deal.II/grid/grid_generator.h b/include/deal.II/grid/grid_generator.h
index a7395bba71..bc5e368afd 100644
--- a/include/deal.II/grid/grid_generator.h
+++ b/include/deal.II/grid/grid_generator.h
@@ -572,9 +572,12 @@ namespace GridGenerator
    * Initialize the given triangulation with a hyper-L (in 2d or 3d)
    * consisting of exactly <tt>2^dim-1</tt> cells. It produces the hypercube
    * with the interval [<i>left,right</i>] without the hypercube made out of
    * the interval [<i>(left+right)/2,right</i>] for each coordinate.  All
    * faces will have boundary indicator 0. This function will create the
    * classical L-shape in 2d and it will look like the following in 3d:
    *
    * @image html hyper_l.png
    *
@@ -586,7 +589,8 @@ namespace GridGenerator
   template <int dim>
   void hyper_L (Triangulation<dim> &tria,
                 const double        left = -1.,
-                const double        right= 1.);
+                const double        right= 1.,
+                const bool          colorize = false);
 
   /**
    * Initialize the given Triangulation with a hypercube with a slit. In each
@@ -572,9 +572,12 @@ namespace GridGenerator
    * consisting of exactly <tt>2^dim-1</tt> cells. It produces the hypercube
    * with the interval [<i>left,right</i>] without the hypercube made out of
-   * the interval [<i>(left+right)/2,right</i>] for each coordinate.  All
-   * faces will have boundary indicator 0. This function will create the
-   * classical L-shape in 2d and it will look like the following in 3d:
+   * the interval [<i>(left+right)/2,right</i>] for each coordinate. If the 
+   * @p colorize flag is set, the @p boundary_ids of the surfaces are
+   * assigned, such that the left boundary is 0, and the others are set with
+   * growing number accordingly to the counterclockwise. This function will 
+   * create the classical L-shape in 2d and it will look like the following 
+   * in 3d:
    *
    * @image html hyper_l.png
-- 
2.39.5